typetraits

package
v0.0.0-...-98bbd2d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package typetraits provides traits that can be used to restrict behaviour.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type NoCompare

type NoCompare struct {
	// contains filtered or unexported fields
}

NoCompare can be embedded into a struct to prevent comparison.

type NoCopy

type NoCopy struct{}

NoCopy can be embedded into a struct to warn against copy.

func (*NoCopy) Lock

func (n *NoCopy) Lock()

func (*NoCopy) Unlock

func (n *NoCopy) Unlock()

Jump to